==> iiimf-skk-0.1.20.6.tar.gz: iiimf-skk-0.1.20.6/lib/skkconv_jisx0201_kana.h <==
/*
 * LibSKK, a tiny Library to emulate SKK (Simple Kana Kanji Conversion)
 * 
 * Copyright (C) 2002 Motonobu Ichimura <famao@kondara.org>
 *
 * All rights reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, and/or sell copies of the Software, and to permit persons
 * to whom the Software is furnished to do so, provided that the above
 * copyright notice(s) and this permission notice appear in all copies of
 * the Software and that both the above copyright notice(s) and this
 * permission notice appear in supporting documentation.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT
 * OF THIRD PARTY RIGHTS. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
 * HOLDERS INCLUDED IN THIS NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL
 * INDIRECT OR CONSEQUENTIAL DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING
 * FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
 * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
 * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale, use
 * or other dealings in this Software without prior written authorization
 * of the copyright holder.
 *
 */

/* $Id$ */

/* vi:set ts=4 sw=4: */


#ifndef HAVE_SKKCONV_JISX0201_KANA_H
#define HAVE_SKKCONV_JISX0201_KANA_H

#include <glib.h>

typedef struct _jisx0201_rule_list jisx0201_rule_list;

struct _jisx0201_rule_list
{
	gchar *jisx0201_kana;
	gchar *katakana;
};

extern jisx0201_rule_list jisx0201_list[];

#define SKKCONV_JISX0201_SIZE (((sizeof (jisx0201_list)) / (sizeof (jisx0201_list[0]))))

gchar *skkconv_hiragana_to_jisx0201_kana (const gchar *hiragana);
gchar *skkconv_katakana_to_jisx0201_kana (const gchar *katakana);
gchar *skkconv_jisx0201_kana_to_katakana (const gchar *jisx0201);

#endif /* HAVE_SKKCONV_JISX0201_KANA_H */

==> iiimf-skk-0.1.20.7.tar.gz: iiimf-skk-0.1.20.7/lib/skkconv_jisx0201_kana.h <==
/*
 * LibSKK, a tiny Library to emulate SKK (Simple Kana Kanji Conversion)
 * 
 * Copyright (C) 2002 Motonobu Ichimura <famao@kondara.org>
 *
 * All rights reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, and/or sell copies of the Software, and to permit persons
 * to whom the Software is furnished to do so, provided that the above
 * copyright notice(s) and this permission notice appear in all copies of
 * the Software and that both the above copyright notice(s) and this
 * permission notice appear in supporting documentation.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT
 * OF THIRD PARTY RIGHTS. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
 * HOLDERS INCLUDED IN THIS NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL
 * INDIRECT OR CONSEQUENTIAL DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING
 * FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
 * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
 * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale, use
 * or other dealings in this Software without prior written authorization
 * of the copyright holder.
 *
 */

/* $Id$ */

/* vi:set ts=4 sw=4: */


#ifndef HAVE_SKKCONV_JISX0201_KANA_H
#define HAVE_SKKCONV_JISX0201_KANA_H

#include <glib.h>

typedef struct _jisx0201_rule_list jisx0201_rule_list;

struct _jisx0201_rule_list
{
	gchar *jisx0201_kana;
	gchar *katakana;
};

extern jisx0201_rule_list jisx0201_list[];

#define SKKCONV_JISX0201_SIZE (((sizeof (jisx0201_list)) / (sizeof (jisx0201_list[0]))))

gchar *skk_conv_hiragana_to_jisx0201_kana (const gchar *hiragana);
gchar *skk_conv_katakana_to_jisx0201_kana (const gchar *katakana);
gchar *skk_conv_jisx0201_kana_to_katakana (const gchar *jisx0201);

#endif /* HAVE_SKKCONV_JISX0201_KANA_H */
